import { a } from "x";
import b from "y";
const arr = (a, b());
